# Expandable module of statistical data utilities

## Requirements:  
- **Jupyter Notebook**, **R**, **Stata**, **Julia**, **GAMS**, **AMPL**, and **Octave/Matlab** (at least some of
the mentioned)
- installed **stata-kernel**, **r2py**, and **oct2py** from PyPi
- **julia**, **gams**, and **ampl** in PATH

## Functions:
`autorun(path_data='...', pattern='...')`  

Cross-platform .ipynb, .R, .do, .jl, .gms, .run, and .m file **batch runner**.
